==> cdi-tck-impl-1.2.1.Final-sources.jar: org/jboss/cdi/tck/interceptors/tests/bindings/broken/InvalidTransitiveInterceptorBindingAnnotationsTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.bindings.broken;

import javax.enterprise.inject.spi.DefinitionException;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.ShouldThrowException;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.descriptor.api.Descriptors;
import org.jboss.shrinkwrap.descriptor.api.beans10.BeansDescriptor;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Test conflicting transitive interceptor bindings.
 */
@SpecVersion(spec = "int", version = "1.2")
public class InvalidTransitiveInterceptorBindingAnnotationsTest extends AbstractTest {

    @ShouldThrowException(DefinitionException.class)
    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder()
                .withTestClass(InvalidTransitiveInterceptorBindingAnnotationsTest.class)
                .withClasses(Foo.class, FooBinding.class, BarBinding.class, BazBinding.class, FooInterceptor.class,
                        BarInterceptor.class, YesBazInterceptor.class, NoBazInterceptor.class)
                .withBeansXml(
                        Descriptors
                                .create(BeansDescriptor.class)
                                .createInterceptors()
                                .clazz(FooInterceptor.class.getName(), BarInterceptor.class.getName(),
                                        YesBazInterceptor.class.getName(), NoBazInterceptor.class.getName()).up()).build();
    }

    @Test
    @SpecAssertion(section = "3.4.2", id = "d")
    public void testInterceptorBindingsWithConflictingAnnotationMembersNotOk() {
    }
}

==> cdi-tck-impl-2.0.0.Final-sources.jar: org/jboss/cdi/tck/interceptors/tests/bindings/broken/InvalidTransitiveInterceptorBindingAnnotationsTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.interceptors.tests.bindings.broken;

import javax.enterprise.inject.spi.DefinitionException;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.ShouldThrowException;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.descriptor.api.Descriptors;
import org.jboss.shrinkwrap.descriptor.api.beans11.BeansDescriptor;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * Test conflicting transitive interceptor bindings.
 */
@SpecVersion(spec = "int", version = "1.2")
public class InvalidTransitiveInterceptorBindingAnnotationsTest extends AbstractTest {

    @ShouldThrowException(DefinitionException.class)
    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder()
                .withTestClass(InvalidTransitiveInterceptorBindingAnnotationsTest.class)
                .withClasses(Foo.class, FooBinding.class, BarBinding.class, BazBinding.class, FooInterceptor.class,
                        BarInterceptor.class, YesBazInterceptor.class, NoBazInterceptor.class)
                .withBeansXml(
                        Descriptors
                                .create(BeansDescriptor.class)
                                .getOrCreateInterceptors()
                                .clazz(FooInterceptor.class.getName(), BarInterceptor.class.getName(),
                                        YesBazInterceptor.class.getName(), NoBazInterceptor.class.getName()).up()).build();
    }

    @Test
    @SpecAssertion(section = "3.4.2", id = "d")
    public void testInterceptorBindingsWithConflictingAnnotationMembersNotOk() {
    }
}
